# Foo

"code1": `code1`

"code2": This is `code2`.

"code spaces": This one has `code spaces`.

"code link": This one is in a `code link`.

"not code": Here’s some `literal backticks`

"multi-backtick code": This code is `delimited ``` by two `s`, so it can include single or triple backticks.

"code block"

    This is a code block.

"tilda code block"

    this code block has tildas,
    <code data-opaque bs-autolink-syntax='```
    and isn&apos;t closed by backticks
    ```'>and isn't closed by backticks</code>
    TODO: move fixText() into the markdown handler, so it doesn’t operate on raw lines;
    TODO: right now it’ll make replacements in scripts, which is obviously bad :(

foo

"long code block"

    this code block starts with 4 backticks
    ```
    so it’s not closed by the 3 backticks above
    but it’s closed with way more than 4 backticks

some final non-code text to make sure things get closed correctly